@@ -20,6 +20,7 @@ from .utils import (
     has_brew,
     run_command,
     win_path_check,
+    win_vmaf_model_path_check,
 )
 
 logger = logging.getLogger("ffmpeg-quality-metrics")
@@ -258,7 +259,7 @@ class FfmpegQualityMetrics:
 
     def calculate(
         self, metrics=["ssim", "psnr"], vmaf_options: Union[VmafOptions, None] = None
-    ):
+    ) -> Dict[str, SingleMetricData]:
         """Calculate one or more metrics.
 
         Args:
@@ -300,8 +301,8 @@ class FfmpegQualityMetrics:
 
         filter_chains = [
             f"[1][0]scale2ref=flags={self.scaling_algorithm}[dist][ref]",
-            "[dist]settb=1/AVTB,setpts=PTS-STARTPTS[distpts]",
-            "[ref]settb=1/AVTB,setpts=PTS-STARTPTS[refpts]",
+            "[dist]settb=AVTB,setpts=PTS-STARTPTS[distpts]",
+            "[ref]settb=AVTB,setpts=PTS-STARTPTS[refpts]",
         ]
 
         # generate split filters depending on the number of models
@@ -353,7 +354,7 @@ class FfmpegQualityMetrics:
         """
         # we only have one model, and its path parameter is not optional
         all_model_params: Dict[str, str] = {
-            "path": win_path_check(self.vmaf_model_path),
+            "path": win_vmaf_model_path_check(self.vmaf_model_path)
         }
 
         # add further model parameters
